@@ -1,8 +1,35 @@
+/* Time-stamp: <2007-10-05 01:59:19 poser> */
+/*
+ * Copyright (C) 1993-2007 William J. Poser.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of version 3 of the GNU General Public License as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * or go to the web page:  http://www.gnu.org/licenses/gpl.txt.
+ *	 
+ */
+
 #include "config.h"
 #include "compdefs.h"
 #include <stdlib.h>
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
 #include <wchar.h>
 #include <stdio.h>
+#ifdef HAVE_UNINUM_UNICODE_H
+#include <uninum/unicode.h>
+#else
+#include "unicode.h"
+#endif
 #include "dstr.h"
 #include "exitcode.h"
 
